#!/bin/bash

set -e
set -x
VERSION=$(git describe --always --tags | sed -e 's/^v//;s/-/_/g')

cat <<EOF > libnfsidmap.spec
Name:           libnfsidmap-files
Version:        ${VERSION}
Release:        1%{?dist}
Summary:        libnfsidmap plugin reading from files
Group:          System
License:        GPLv3+
URL:            https://gitlab.control.lth.se/anders_blomdell/libnfsidmap-files

Source0:        libnfsidmap-files-${VERSION}.tar.gz

BuildRequires:  gcc
BuildRequires:  libnfsidmap-devel
BuildRequires:  automake
BuildRequires:  autoconf
BuildRequires:  m4
BuildRequires:  libtool

Requires:       libnfsidmap

%description
libnfsidmap plugin reading from files

%prep
%autosetup 
./autogen.sh

%build
%configure
make

%install
mkdir -p %{buildroot}/%{_libdir}/libnfsidmap/
mkdir -p %{buildroot}/%{_mandir}/man5
/usr/bin/install .libs/files.so %{buildroot}/%{_libdir}/libnfsidmap/
/usr/bin/install libnfsidmap-files.5 %{buildroot}/%{_mandir}/man5/

%check
make test

%files
%{_libdir}/libnfsidmap/files.so
%{_mandir}/man5/*

EOF
git archive --format tar --prefix libnfsidmap-files-${VERSION}/ HEAD \
    | gzip > libnfsidmap-files-${VERSION}.tar.gz

rpmbuild --define "_topdir $(pwd)" \
         --define "_builddir $(pwd)" \
         --define "_rpmdir $(pwd)" \
         --define "_sourcedir $(pwd)" \
         --define "_specdir $(pwd)" \
         --define "_srcrpmdir $(pwd)" \
         --define "_buildrootdir $(pwd)" \
         -bs libnfsidmap.spec

exit 0
FILES_VERSION = $(shell sha512toc.spec git describe --always | sed -e 's/^v//;s/-/_/g')

libnfsidmap-files.tar: $(SOURCES)
	tar -cvf $@ --transform 's|.*|sha512toc/&|' $^

libnfsidmap-files.spec: libnfsidmap-files.spec.template Makefile
	sed -e 's/__FILES_VERSION__/$(FILES_VERSION)/' $< > $@

	libnfsidmap-files.spec $(FILES_VERSION).tar Makefile
	rpmbuild --define "_topdir $$(pwd)" \
                 --define "_builddir $$(pwd)" \
                 --define "_rpmdir $$(pwd)" \
                 --define "_sourcedir $$(pwd)" \
                 --define "_specdir $$(pwd)" \
                 --define "_srcrpmdir $$(pwd)" \
                 --define "_buildrootdir $$(pwd)" \
                 -bs $<
